@@ -2,6 +2,7 @@ from seti_python.class_read import (
     ResponseReadCash,
     ResponseReadCashOut,
     ResponseReadPayment,
+    ResponseReadSingleTransactions,
     ResponseReadTransactions,
     ResponseReadWallet,
     ResponseReadWalletsTransactions,
@@ -368,3 +369,13 @@ class Seti:
         return CompleteBasicaResponse(
             self.send_request(data_read_cash, encode_data, REVERT_TRANSACTION_URL)
         )
+
+
+    def read_single_transaction(self,transaction_id:str):
+        self.is_error = False
+        data_read_cash = {"transactionId": transaction_id}
+        REVERT_TRANSACTION_URL = "read-transaction"
+        encode_data = self.sign_data(data_read_cash)
+        return ResponseReadSingleTransactions(
+            self.send_request(data_read_cash, encode_data, REVERT_TRANSACTION_URL)
+        )
