@@ -33,7 +33,8 @@ class NewUsers:
         except Exception:
             self.secret = ""
 
-
+    def __repr__(self):
+        return str(self.__dict__)
 class ResponseCreateUser(BasicResponse):
     data: NewUsers
 
